==> scummvm_2.7.0+dfsg.orig.tar.xz: scummvm-2.7.0+dfsg/engines/wintermute/base/save_thumb_helper.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

/*
 * This file is based on WME Lite.
 * http://dead-code.org/redir.php?target=wmelite
 * Copyright (c) 2011 Jan Nedoma
 */
#ifndef WINTERMUTE_BASE_SAVE_THUMB_HELPER_H
#define WINTERMUTE_BASE_SAVE_THUMB_HELPER_H

namespace Wintermute {

class BaseImage;
class BaseGame;

class SaveThumbHelper {
public:
	SaveThumbHelper(BaseGame *inGame);
	virtual ~SaveThumbHelper(void);
	bool storeThumbnail(bool doFlip = false);
	bool storeScummVMThumbNail(bool doFlip = false);

	BaseImage *_thumbnail;
	BaseImage *_scummVMThumb;
private:
	BaseImage *storeThumb(bool doFlip, int width, int height);
	BaseGame *_gameRef;
};

} // End of namespace Wintermute

#endif

==> scummvm-2026.1.0.tar.xz: scummvm-2026.1.0/engines/wintermute/base/save_thumb_helper.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

/*
 * This file is based on WME Lite.
 * http://dead-code.org/redir.php?target=wmelite
 * Copyright (c) 2011 Jan Nedoma
 */
#ifndef WINTERMUTE_BASE_SAVE_THUMB_HELPER_H
#define WINTERMUTE_BASE_SAVE_THUMB_HELPER_H

namespace Wintermute {

class BaseImage;
class BaseGame;

class SaveThumbHelper {
public:
	SaveThumbHelper(BaseGame *inGame);
	virtual ~SaveThumbHelper();
	bool storeThumbnail(bool doFlip = false);
	bool storeScummVMThumbNail(bool doFlip = false);

	BaseImage *_thumbnail;
	BaseImage *_scummVMThumb;
private:
	BaseImage *storeThumb(bool doFlip, int width, int height);
	BaseGame *_game;
};

} // End of namespace Wintermute

#endif
